==> neo-jquery-1.0.8.tgz: package/components/accordion.js <==
class Accordion extends HTMLElement {
    title;
    constructor() {
        super();
        this.title;
    }
    static get observedAttribute() {
        return ['title'];
    }
    connectedCallback() {
        // shadow root
        const shadowRoot = this.attachShadow({ mode: 'open' });
        // elements
        const styles = document.createElement('style');
        const accContainer = document.createElement('details');
        const accTitle = document.createElement('summary');
        const accPanel = document.createElement('slot');
        // styles accordion
        styles.textContent = `
      .accordion-title, ::slotted(.accordion-panel) {
        width: 100%;
      }

      ::slotted(.accordion-panel) {
        height: auto;
        padding: var(--accordion-panel-padding);
        background-color: var(--accordion-panel-bg);
        color: var(--accordion-panel-textColor);
        overflow: auto;
        margin: 0;
      }

      .accordion-title {
        background-color: var(--accordion-title-bg);
        color: var(--accordion-title-textColor);
        cursor: pointer;
        padding: var(--accordion-title-padding);
        outline: none;
        list-style: none;
        font-size: var(--accordion-title-fs);
        transition: 0.5s;
      }
    `;
        // accordion title params
        accTitle.textContent = this.title;
        accTitle.classList.add('accordion-title');
        // append accordion container
        accContainer.append(accTitle, accPanel);
        // shadow append
        shadowRoot.append(styles, accContainer);
    }
}
// create custom Element
customElements.define('neo-accordion', Accordion);

==> neo-jquery-1.1.7.tgz: package/components/accordion.js <==
class Accordion extends HTMLElement {
    title;
    constructor() {
        super();
        this.title;
    }
    static get observedAttribute() {
        return ['title'];
    }
    connectedCallback() {
        // shadow root
        const shadowRoot = this.attachShadow({ mode: 'open' });
        // elements
        const styles = document.createElement('style');
        const accContainer = document.createElement('details');
        const accTitle = document.createElement('summary');
        const accPanel = document.createElement('slot');
        // styles accordion
        styles.textContent = `
      .accordion-title, ::slotted(.accordion-panel) {
        width: 100%;
      }

      ::slotted(.accordion-panel) {
        height: auto;
        padding: var(--accordion-panel-padding, 0 18px);
        background-color: var(--accordion-panel-bg, #fff);
        color: var(--accordion-panel-textColor, #000);
        overflow: auto;
        margin: 0;
      }

      .accordion-title {
        background-color: var(--accordion-title-bg, #0f0);
        color: var(--accordion-title-textColor, #fff);
        cursor: pointer;
        padding: var(--accordion-title-padding, 18px);
        outline: none;
        list-style: none;
        font-size: var(--accordion-title-fs, 16px);
        transition: 0.5s;
      }
    `;
        // accordion title params
        accTitle.textContent = this.title;
        accTitle.classList.add('accordion-title');
        // append accordion container
        accContainer.append(accTitle, accPanel);
        // shadow append
        shadowRoot.append(styles, accContainer);
    }
}
// create custom Element
customElements.define('neo-accordion', Accordion);
